---
name: Vulnerability report
about: Report a vulnerability in boto34
title: "Vulnerability report:"
labels: "🐞 bug"
assignees: ""
---

**Describe the vulnerability**
A clear and concise description of what the vulnerability is.

**Additional context**

Product: `boto34`
Version: `x.x.x`
